"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MovingPlatformPlayerUpdateEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when the player on a moving platform is updated. This is also when
 * the moving platform moves left or right.
 */
class MovingPlatformPlayerUpdateEvent extends events_1.RevertableEvent {
    constructor(room, movingplatform, message, 
    /**
     * The player on the moving platform, if any.
     */
    player, 
    /**
     * The direction that the moving platform is moving in.
     */
    side) {
        super();
        this.room = room;
        this.movingplatform = movingplatform;
        this.message = message;
        this.player = player;
        this.side = side;
        this.eventName = "movingplatform.updateplayer";
        this._alteredPlayer = player;
        this._alteredSide = side;
    }
    /**
     * The altered player that will be on the moving platform, if changed.
     */
    get alteredPlayer() {
        return this._alteredPlayer;
    }
    /**
     * The altered direction that the moving platfomr will move in, if changed.
     */
    get alteredSide() {
        return this._alteredSide;
    }
    /**
     * Change the player that is on the moving platform.
     * @param player The player to get onto the moving platform.
     */
    setPlayer(player) {
        this._alteredPlayer = player;
    }
    /**
     * Change the direction that the moving platform is moving in.
     * @param side The direction for the moving platform to move.
     */
    setSide(side) {
        this._alteredSide = side;
    }
}
exports.MovingPlatformPlayerUpdateEvent = MovingPlatformPlayerUpdateEvent;
MovingPlatformPlayerUpdateEvent.eventName = "movingplatform.updateplayer";
//# sourceMappingURL=PlayerUpdate.js.map