"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoomAssignRolesEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when SkeldJS assigns roles to each player, just after a game is started.
 * Can be canceled to avoid assigning roles entirely, or can be used to change
 * which roles are assigned to which players.
 *
 * Does not guarantee that the players' roles have actually been assigned, see
 * {@link PlayerSetRoleEvent}.
 */
class RoomAssignRolesEvent extends events_1.CancelableEvent {
    constructor(room, 
    /**
     * The players that were chosen to be impostors.
     */
    roleAssignments) {
        super();
        this.room = room;
        this.roleAssignments = roleAssignments;
        this.eventName = "room.assignroles";
        this._alteredAssignments = new Map(roleAssignments.entries());
    }
    /**
     * Which roles to assign to which players instead, if changed.
     */
    get alteredAssignments() {
        return this._alteredAssignments;
    }
    /**
     * Change which roles to assign to which players.
     * @param roleAssignments The roles to assign instead.
     */
    setAssignments(roleAssignments) {
        this._alteredAssignments = roleAssignments;
    }
    /**
     * Change which role a player will get assigned.
     * @param player The player to change the assignment for.
     * @param assignment The role to assign for the player instead.
     */
    setAssignment(player, assignment) {
        this._alteredAssignments.set(player, assignment);
    }
}
exports.RoomAssignRolesEvent = RoomAssignRolesEvent;
RoomAssignRolesEvent.eventName = "room.assignroles";
//# sourceMappingURL=AssignRoles.js.map